smusic

package module
v0.0.0-...-d389aee Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 20, 2019 License: GPL-3.0 Imports: 10 Imported by: 0

README

smusic

Package smusic is a music player for shop with using Raspberry PI

Documentation

Overview

Package smusic is a music player for shop with using Raspberry PI

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Start

func Start()

Start function initialize media-folders and start to play music

Types

This section is empty.

Directories

Path Synopsis

Jump to